#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 static-hash
version:              0.0.2
visibility:           public
id:                   static-hash-0.0.2-2XdMCxei6TZIJBy567emRq
key:                  static-hash-0.0.2-2XdMCxei6TZIJBy567emRq
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Immutable hash
description:          Pure immutable hash whose lookup is O(1)
category:             Data Structures
abi:                  66d7408cca0593dea563cf345ec2188d
exposed:              True
exposed-modules:      Data.StaticHash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-static-hash
hs-libraries:         HSstatic-hash-0.0.2-2XdMCxei6TZIJBy567emRq
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    primes-0.2.1.0-5dFqmFtEQZu8fMD7oOp1xA

haddock-interfaces:   /usr/share/doc/haskell-static-hash/html/static-hash.haddock
haddock-html:         /usr/share/doc/haskell-static-hash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

